@@ -13,10 +13,10 @@ rename2 <- function(.data, ...) {
 }
 
 exponentiate <- function(data, col = "estimate") {
-  data <- data %>% mutate(across(all_of(col), exp))
+  data <- data |> mutate(across(all_of(col), exp))
 
   if ("conf.low" %in% colnames(data)) {
-    data <- data %>% mutate(across(c(conf.low, conf.high), exp))
+    data <- data |> mutate(across(c(conf.low, conf.high), exp))
   }
 
   data
@@ -34,31 +34,34 @@ exponentiate <- function(data, col = "estimate") {
 #' @return A `tibble` potentially with a `.rownames` column
 #' @noRd
 #'
-
-
-as_augment_tibble <- function(data) {
+as_augment_tibble <- function(
+  data,
+  arg = caller_arg(data),
+  call = caller_env()
+) {
   if (inherits(data, "matrix") & is.null(colnames(data))) {
-    stop(
-      "The supplied `data`/`newdata` argument was an unnamed matrix. ",
-      "Please supply a matrix or dataframe with column names."
-    )
+    cli::cli_abort(c(
+      "{.arg {arg}} is an unnamed matrix.",
+      "i" = "Please supply a matrix or data frame with column names."
+    ))
   }
 
   tryCatch(
     df <- as_tibble(data),
     error = function(cnd) {
-      stop("Could not coerce data to `tibble`. Try explicitly passing a",
-        "dataset to either the `data` or `newdata` argument.",
-        call. = FALSE
+      cli::cli_abort(
+        c(
+          "Could not coerce {.arg {arg}} to a tibble.",
+          "i" = "Try explicitly passing a data frame to either the {.arg data} or
+                 {.arg newdata} argument."
+        ),
+        call = call
       )
     }
   )
 
   if (has_rownames(data)) {
-    df <- tibble::add_column(df,
-      .rownames = rownames(data),
-      .before = TRUE
-    )
+    df <- tibble::add_column(df, .rownames = rownames(data), .before = TRUE)
   }
   df
 }
@@ -67,8 +70,7 @@ as_augment_tibble <- function(data) {
 is_cran_check <- function() {
   if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     FALSE
-  }
-  else {
+  } else {
     Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
   }
 }
@@ -86,7 +88,10 @@ is_cran_check <- function() {
 #' @noRd
 as_tidy_tibble <- function(x, new_names = NULL, new_column = "term") {
   if (!is.null(new_names) && length(new_names) != ncol(x)) {
-    stop("newnames must be NULL or have length equal to number of columns")
+    cli::cli_abort(
+      "{.arg new names} must be {.code NULL} or have length equal to
+       number of columns ({ncol(data)})."
+    )
   }
 
   ret <- x
@@ -117,14 +122,8 @@ as_tidy_tibble <- function(x, new_names = NULL, new_column = "term") {
 #' @param id_column The name of the column giving the name of each
 #' element in `x`
 #' @noRd
-map_as_tidy_tibble <- function(x,
-                               ...,
-                               id_column = "component") {
-  purrr::map_df(x,
-    as_tidy_tibble,
-    ...,
-    .id = id_column
-  )
+map_as_tidy_tibble <- function(x, ..., id_column = "component") {
+  purrr::map_df(x, as_tidy_tibble, ..., .id = id_column)
 }
 
 # copied from modeltests. re-export if at some we Import modeltests rather
@@ -150,11 +149,11 @@ parse_na_types <- function(s) {
     stringr::str_split(s, pattern = ""),
     match,
     table = names(na_types_dict)
-  ) %>%
+  ) |>
     unlist()
 
-  na_types_dict[positions] %>%
-    unlist() %>%
+  na_types_dict[positions] |>
+    unlist() |>
     unname()
 }
 
@@ -164,9 +163,9 @@ as_glance_tibble <- function(..., na_types) {
   cols <- list(...)
 
   if (length(cols) != stringr::str_length(na_types)) {
-    stop(
-      "The number of columns provided does not match the number of ",
-      "column types provided."
+    cli::cli_abort(
+      "The number of columns provided does not match the number of 
+       column {.emph types} provided."
     )
   }
 
@@ -209,12 +208,21 @@ unrowname <- function(x) {
 #' @param type.residuals Type of residuals to compute; by default
 #' same as `type`
 #' @param se.fit Value to pass to predict's `se.fit`, or NULL for
-#' no value
+#' no value. Ignored for model types that do not accept an `se.fit`
+#' argument
 #' @param ... extra arguments (not used)
 #'
 #' @export
-augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
-                            type.residuals = type, se.fit = TRUE, ...) {
+augment_columns <- function(
+  x,
+  data,
+  newdata = NULL,
+  type,
+  type.predict = type,
+  type.residuals = type,
+  se.fit = TRUE,
+  ...
+) {
   notNAs <- function(o) {
     if (is.null(o) || all(is.na(o))) NULL else o
   }
@@ -231,12 +239,13 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
     args$newdata <- newdata
   }
   if (!missing(type.predict)) {
-    args$type <- type.predict
+    args$type <- type.predict[1]
+  }
+  if (!inherits(x, "betareg")) {
+    args$se.fit <- se.fit
   }
-  args$se.fit <- se.fit
   args <- c(args, list(...))
 
-
   if ("panelmodel" %in% class(x)) {
     # work around for panel models (plm)
     # stat::predict() returns wrong fitted values when applied to random or
@@ -279,7 +288,8 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
         ret$.hat <- infl
         ret$.sigma <- NA
       } else {
-        zero_weights <- "weights" %in% names(x) &&
+        zero_weights <- "weights" %in%
+          names(x) &&
           any(zero_weight_inds <- abs(x$weights) < .Machine$double.eps^0.5)
         if (zero_weights) {
           ret[c(".hat", ".sigma")] <- 0
@@ -302,10 +312,12 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
     if (inherits(na_action, "exclude")) {
       # check if values are missing
       if (length(stats::residuals(x)) > nrow(data)) {
-        warning(
-          "When fitting with na.exclude, rows with NA in ",
-          "original data will be dropped unless those rows are provided ",
-          "in 'data' argument"
+        cli::cli_warn(
+          c(
+            "When fitting with {.code na.exclude}, rows with {.code NA}s in
+             original data will be dropped unless those rows are provided
+             in the {.arg data} argument."
+          )
         )
       }
     }
@@ -348,7 +360,11 @@ response <- function(object, newdata = NULL, has_response) {
 
   res <-
     tryCatch(
-      model.response(model.frame(terms(object), data = newdata, na.action = na.pass)),
+      model.response(model.frame(
+        terms(object),
+        data = newdata,
+        na.action = na.pass
+      )),
       error = function(e) NULL
     )
 
@@ -359,10 +375,10 @@ response <- function(object, newdata = NULL, has_response) {
   res
 }
 
-data_error <- function(cnd) {
-  stop(
-    "Must specify either `data` or `newdata` argument.",
-    call. = FALSE
+data_error <- function(cnd, call = caller_env()) {
+  cli::cli_abort(
+    "Must specify either {.arg data} or {.arg newdata} argument.",
+    call = call
   )
 }
 
@@ -381,10 +397,10 @@ add_hat_sigma_cols <- function(df, x, infl) {
   w <- x$weights
   nonzero_idx <- if (is.null(w)) seq_along(df$.hat) else which(w != 0)
 
-  df$.hat[nonzero_idx] <- infl$hat %>% unname()
-  df$.sigma[nonzero_idx] <- infl$sigma %>% unname()
-  df$.std.resid[nonzero_idx] <- rstandard(x, infl = infl) %>% unname()
-  df$.cooksd[nonzero_idx] <- cooks.distance(x, infl = infl) %>% unname()
+  df$.hat[nonzero_idx] <- infl$hat |> unname()
+  df$.sigma[nonzero_idx] <- infl$sigma |> unname()
+  df$.std.resid[nonzero_idx] <- rstandard(x, infl = infl) |> unname()
+  df$.cooksd[nonzero_idx] <- cooks.distance(x, infl = infl) |> unname()
   df
 }
 
@@ -408,9 +424,10 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
       # TRUE if response includes a function call and is in column names,
       # usually with no `data` or `newdata` supplied,
       # and `data` defaults to `model_frame(x)`
-      rlang::as_label(rlang::f_lhs(x$terms)) %in% names(df) ||
-        # TRUE if the response variable itself is in column names
-        all.vars(x$terms)[1] %in% names(df)
+      rlang::as_label(rlang::f_lhs(x$terms)) %in%
+      names(df) ||
+      # TRUE if the response variable itself is in column names
+      all.vars(x$terms)[1] %in% names(df)
   } else {
     has_response <- FALSE
   }
@@ -431,9 +448,16 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
   # an na.pass argument
 
   if (.se_fit) {
-    pred_obj <- predict(x, newdata = newdata, na.action = na.pass, se.fit = .se_fit, interval = interval, ...)
+    pred_obj <- predict(
+      x,
+      newdata = newdata,
+      na.action = na.pass,
+      se.fit = .se_fit,
+      interval = interval,
+      ...
+    )
     if (is.null(interval) || interval == "none") {
-      df$.fitted <- pred_obj$fit %>% unname()
+      df$.fitted <- pred_obj$fit |> unname()
     } else {
       df$.fitted <- pred_obj$fit[, "fit"]
       df$.lower <- pred_obj$fit[, "lwr"]
@@ -446,26 +470,45 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
     se_idx <- which(names(pred_obj) %in% c("se.fit", "se"))
     df$.se.fit <- pred_obj[[se_idx]]
   } else if (!is.null(interval) && interval != "none") {
-    pred_obj <- predict(x, newdata = newdata, na.action = na.pass, se.fit = FALSE, interval = interval, ...)
+    pred_obj <- predict(
+      x,
+      newdata = newdata,
+      na.action = na.pass,
+      se.fit = FALSE,
+      interval = interval,
+      ...
+    )
     df$.fitted <- pred_obj[, "fit"]
     df$.lower <- pred_obj[, "lwr"]
     df$.upper <- pred_obj[, "upr"]
   } else if (passed_newdata) {
     if (is.null(interval) || interval == "none") {
-      df$.fitted <- predict(x, newdata = newdata, na.action = na.pass, ...) %>%
+      df$.fitted <- predict(x, newdata = newdata, na.action = na.pass, ...) |>
         unname()
     } else {
-      pred_obj <- predict(x, newdata = newdata, na.action = na.pass, interval = interval, ...)
+      pred_obj <- predict(
+        x,
+        newdata = newdata,
+        na.action = na.pass,
+        interval = interval,
+        ...
+      )
       df$.fitted <- pred_obj$fit[, "fit"]
       df$.lower <- pred_obj$fit[, "lwr"]
       df$.upper <- pred_obj$fit[, "upr"]
     }
   } else {
     if (is.null(interval) || interval == "none") {
-      df$.fitted <- predict(x, na.action = na.pass, ...) %>%
+      df$.fitted <- predict(x, na.action = na.pass, ...) |>
         unname()
     } else {
-      pred_obj <- predict(x, newdata = newdata, na.action = na.pass, interval = interval, ...)
+      pred_obj <- predict(
+        x,
+        newdata = newdata,
+        na.action = na.pass,
+        interval = interval,
+        ...
+      )
       df$.fitted <- pred_obj$fit[, "fit"]
       df$.lower <- pred_obj$fit[, "lwr"]
       df$.upper <- pred_obj$fit[, "upr"]
@@ -475,7 +518,7 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
   resp <- safe_response(x, df, has_response)
 
   if (!is.null(resp) && is.numeric(resp)) {
-    df$.resid <- (resp - df$.fitted) %>% unname()
+    df$.resid <- (resp - df$.fitted) |> unname()
   }
 
   df
@@ -527,7 +570,9 @@ warn_on_subclass <- function(x, tidier) {
 
     rlang::warn(
       paste0(
-        "The `", tidier, "()` method for objects of class `",
+        "The `",
+        tidier,
+        "()` method for objects of class `",
         subclass,
         "` is not maintained by the broom team, and is only supported through ",
         "the `",
@@ -586,6 +631,7 @@ globalVariables(
     "group1",
     "group2",
     "hat",
+    "id",
     "idx",
     "index",
     "Intercept",
@@ -659,8 +705,13 @@ check_ellipses <- function(arg, fn, cls, ...) {
 
   if (arg %in% names(dots)) {
     rlang::warn(paste0(
-      "The `", arg, "` argument is not supported in the `", fn,
-      "()` method for `", cls, "` objects and will be ignored."
+      "The `",
+      arg,
+      "` argument is not supported in the `",
+      fn,
+      "()` method for `",
+      cls,
+      "` objects and will be ignored."
     ))
   }
 
