@@ -1,5 +1,3 @@
-context("stats-lm")
-
 skip_if_not_installed("modeltests")
 library(modeltests)
 
@@ -35,7 +33,7 @@ test_that("tidy.lm works", {
 
   # conf.int = TRUE works for rank deficient fits
   # should get a "NaNs produced" warning
-  expect_warning(td_rd <- tidy(fit_rd, conf.int = TRUE))
+  expect_snapshot(td_rd <- tidy(fit_rd, conf.int = TRUE))
 
   check_tidy_output(td)
   check_tidy_output(td2)
@@ -52,9 +50,9 @@ test_that("tidy.lm works", {
   expect_equal(td2$term, c("(Intercept)", "wt", "log(disp)"))
   expect_equal(td3$term, c("(Intercept)"))
 
-  # shouldn't error. regression test for issues 166, 241
+  # shouldn't error. regression test for issues #166 and #241.
   # rows for confidence intervals of undefined terms should be dropped
-  expect_error(tidy(fit_na_row, conf.int = TRUE), NA)
+  expect_no_error(tidy(fit_na_row, conf.int = TRUE))
 })
 
 test_that("glance.lm", {
@@ -74,7 +72,6 @@ test_that("augment.lm", {
     newdata = mtcars
   )
 
-
   check_augment_function(
     aug = augment.lm,
     model = fit2,
@@ -122,13 +119,23 @@ test_that("augment.lm", {
   expect_equal(aug$.upper, pred[, "upr"])
 
   # conf.level is respected
-  aug <- augment(fit, newdata = mtcars, interval = "confidence", conf.level = 0.75)
+  aug <- augment(
+    fit,
+    newdata = mtcars,
+    interval = "confidence",
+    conf.level = 0.75
+  )
   pred <- predict(fit, newdata = mtcars, interval = "confidence", level = 0.75)
   expect_equal(aug$.lower, pred[, "lwr"])
   expect_equal(aug$.upper, pred[, "upr"])
 
   # conf.level works for prediction intervals as well
-  aug <- augment(fit, newdata = mtcars, interval = "prediction", conf.level = 0.25)
+  aug <- augment(
+    fit,
+    newdata = mtcars,
+    interval = "prediction",
+    conf.level = 0.25
+  )
   pred <- predict(fit, newdata = mtcars, interval = "prediction", level = 0.25)
   expect_equal(aug$.lower, pred[, "lwr"])
   expect_equal(aug$.upper, pred[, "upr"])
@@ -136,11 +143,10 @@ test_that("augment.lm", {
   # conf.level is ignored when interval = "none"
   aug <- augment(fit, newdata = mtcars, interval = "none", conf.level = 0.25)
   expect_false(any(names(aug) %in% c(".lower", ".upper")))
-  
+
   # warns when passed as level rather than conf.level
-  expect_warning(
-    augment(fit, newdata = mtcars, interval = "confidence", level = 0.95),
-    "\\`level\\` argument is not supported in the \\`augment\\(\\)\\` method for \\`lm\\` objects"
+  expect_snapshot(
+    augment(fit, newdata = mtcars, interval = "confidence", level = 0.95)
   )
 })
 
