@@ -1,5 +1,3 @@
-context("stats-mlm")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
@@ -10,7 +8,7 @@ df_tidy <- tidy(fit_mlm, conf.int = TRUE)
 
 test_that("tidy.mlm works", {
   expect_equal(dim(df_tidy), c(4L, 8L))
-  expect_is(df_tidy, "tbl_df")
+  expect_s3_class(df_tidy, "tbl_df")
 })
 
 #' helper function: replicate each element of x
@@ -18,7 +16,8 @@ test_that("tidy.mlm works", {
 rep_each <- function(x, times) {
   retv <- outer(rep(1, times), x, function(x, y) y)
   dim(retv) <- c(prod(dim(retv)), 1)
-  retv <- switch(class(x),
+  retv <- switch(
+    class(x),
     character = as.character(retv),
     numeric = as.numeric(retv),
     integer = as.integer(retv),
@@ -37,7 +36,7 @@ test_that("tidy.mlm works", {
       x2 = runif(nob),
       z1 = rnorm(nob),
       z2 = rnorm(nob)
-    ) %>%
+    ) |>
     dplyr::mutate(
       y1 = 0.5 * x1 + x2 + z1 - z2,
       y2 = -2 * x1 + 0.25 * x2 + 3 * z1 + z2
